Crate openvm_circuit

Crate openvm_circuit 

Re-exports

pub use openvm_circuit_derive as derive;
pub use openvm_circuit_primitives as primitives;
pub use openvm_circuit_primitives_derive as circuit_derive;

Modules

arch
Traits and constructs for the OpenVM architecture.
system
System chips that are always required by the architecture. (The PhantomChip is not technically required for a functioning VM, but there is almost always a need for it.)
utils
Utility functions and test utils

Macros

execute_spanned
Macro for executing and emitting metrics for instructions/s and number of instructions executed. Does not include any tracing span.